@@ -73,6 +73,8 @@ graphab_to_igraph <- function(proj_name,
   # Check whether the input fig and crds are logical
   if(!all(c(is.logical(fig),
             is.logical(crds)))){
+    # Before returning an error, get back to initial working dir
+    if(chg == 1){setwd(dir = wd1)}
     stop("Inputs 'fig' and 'crds' must be TRUE or FALSE")
   }
 
@@ -91,8 +93,12 @@ graphab_to_igraph <- function(proj_name,
   #########################################
   # Check for proj_name class
   if(!inherits(proj_name, "character")){
+    # Before returning an error, get back to initial working dir
+    if(chg == 1){setwd(dir = wd1)}
     stop("'proj_name' must be a character string")
   } else if (!(paste0(proj_name, ".xml") %in% list.files(path = paste0("./", proj_name)))){
+    # Before returning an error, get back to initial working dir
+    if(chg == 1){setwd(dir = wd1)}
     stop("The project you refer to does not exist.
          Please use graphab_project() before.")
   }
@@ -101,13 +107,19 @@ graphab_to_igraph <- function(proj_name,
   #########################################
   # Check for linkset class
   if(!inherits(linkset, "character")){
+    # Before returning an error, get back to initial working dir
+    if(chg == 1){setwd(dir = wd1)}
     stop("'linkset' must be a character string")
   } else if (length(list.files(path = paste0("./", proj_name),
                                pattern = "-links.csv")) == 0){
+    # Before returning an error, get back to initial working dir
+    if(chg == 1){setwd(dir = wd1)}
     stop("There is not any linkset in the project you refer to.
          Please use graphab_link() before.")
   } else if (!(paste0(linkset, "-links.csv") %in% list.files(path = paste0("./",
                                                                            proj_name)))){
+    # Before returning an error, get back to initial working dir
+    if(chg == 1){setwd(dir = wd1)}
     stop("The linkset you refer to does not exist.
            Please use graphab_link() before.")
   }
@@ -115,6 +127,8 @@ graphab_to_igraph <- function(proj_name,
   #########################################
   # Check for nodes
   if(!inherits(nodes, "character")){
+    # Before returning an error, get back to initial working dir
+    if(chg == 1){setwd(dir = wd1)}
     stop("'nodes' must be a character string.")
   } else if(!file.exists(paste0("./", proj_name, "/patches.csv"))){
     df_nodes <- foreign::read.dbf(file = paste0("./", proj_name, "/patches.dbf"))
@@ -128,11 +142,15 @@ graphab_to_igraph <- function(proj_name,
   if(nodes != "patches"){
 
     if (length(list.files(path = paste0("./", proj_name), pattern = "-voronoi.shp")) == 0){
+      # Before returning an error, get back to initial working dir
+      if(chg == 1){setwd(dir = wd1)}
       stop("There is not any graph in the project you refer to.
          Please use graphab_graph() before.")
     } else if(!(paste0(nodes,
                        "-voronoi.shp") %in% list.files(path = paste0("./",
                                                                      proj_name)))){
+      # Before returning an error, get back to initial working dir
+      if(chg == 1){setwd(dir = wd1)}
       stop("The graph you refer to does not exist")
 
     } else {
@@ -166,6 +184,8 @@ graphab_to_igraph <- function(proj_name,
     } else if (weight == "euclid"){
       igraph::E(graph)$weight <- df_links[, "DistM"]
     } else {
+      # Before returning an error, get back to initial working dir
+      if(chg == 1){setwd(dir = wd1)}
       stop("You must specify a correct 'weight' option ('cost' or 'euclid').")
     }
 
@@ -198,6 +218,8 @@ graphab_to_igraph <- function(proj_name,
       df <- df[-which(df$Id %in% df_links$Id), ]
       df <- rbind(df, df_links)
     } else {
+      # Before returning an error, get back to initial working dir
+      if(chg == 1){setwd(dir = wd1)}
       stop("Error probably due to unusual structure
            of the links spatial layer.")
     }
@@ -213,6 +235,8 @@ graphab_to_igraph <- function(proj_name,
     } else if (weight == "euclid"){
       igraph::E(graph)$weight <- df[, "DistM"]
     } else {
+      # Before returning an error, get back to initial working dir
+      if(chg == 1){setwd(dir = wd1)}
       stop("You must specify a correct 'weight' option ('cost' or 'euclid').")
     }
 
